@@ -18,7 +18,6 @@
 #define CH_PASSWD_H
 
 #include "ui_ch_passwd.h"
-
 #include <QMessageBox>
 #include <QSettings>
 
@@ -42,6 +41,9 @@ class ChangePassword : public QDialog, public Ui::ChangePassword {
      void checkNewPW();
      void savePW();
 
+    protected:
+     virtual void closeEvent(QCloseEvent* close_ch_pw);
+
 };
 
 #endif //CH_PASSWD_H
