@@ -78,14 +78,15 @@ bool Editor::getLockAll(){
 #else //!Q_OS_WIN32
      QString file(QDir::homePath() + "/.qshutdown/qshutdown.conf");
 #endif //Q_OS_WIN32
-     QSettings settings(file, QSettings::NativeFormat);
+     QSettings settings(file, QSettings::IniFormat);
      return settings.value("Lock_all").toBool();
 }
 
 void Editor::keyPressEvent(QKeyEvent *kEvent){
      if((kEvent->modifiers() == Qt::ControlModifier) && (kEvent->key() == Qt::Key_S))
        saveChanges();
-     if((kEvent->modifiers() == Qt::ControlModifier) && (kEvent->key() == Qt::Key_Q))
+     if(((kEvent->modifiers() == Qt::ControlModifier) && (kEvent->key() == Qt::Key_Q))
+         || (kEvent->key() == Qt::Key_Escape))
        reject();
 }
 
