@@ -30,7 +30,15 @@ Gui::Gui(){
 
      setupUi(this);
 
-     finishedExecuted = false;
+   //Seconds won't be recognized, thus removing them (just in case).
+     QString timeEditFormat;
+     timeEditFormat = timeEdit->displayFormat();
+     if(timeEditFormat.contains(":ss"))
+       timeEditFormat.replace(QString(":ss"), QString(""));
+     if(timeEditFormat.contains(":s"))
+       timeEditFormat.replace(QString(":s"), QString(""));
+     timeEdit->setDisplayFormat(timeEditFormat);
+
      timeRunning = false;
      logFileSize = 1.5;
 
@@ -56,10 +64,21 @@ Gui::Gui(){
      QFile versionFile(":version");
      versionFile.open(QIODevice::ReadOnly | QIODevice::Text);
      QTextStream in(&versionFile);
-     QString string = in.readLine();
-     version->setText(string);
+     statusBar()->showMessage(tr("Version ") + in.readLine(),15000);
      versionFile.close();
 
+/* //Parental lock label for the statusbar
+     parentalLockL = new QLabel(tr("locked"));
+     parentalLockL->setFrameShape(QFrame::Box);
+     parentalLockL->setFrameShadow(QFrame::Sunken);
+     parentalLockL->setToolTip(tr("Parental lock is activated"));
+
+   //Custom mode label for the statusbar
+     customL = new QLabel(tr("custom"));
+     customL->setFrameShape(QFrame::Box);
+     customL->setFrameShadow(QFrame::Sunken);
+     customL->setToolTip(tr("Using user defined command"));*/
+
    //About
      about = new About(this);
 
@@ -176,8 +195,10 @@ Gui::Gui(){
      connect(checkPassword, SIGNAL(finishing()), this, SLOT(warnings_on()));
 
      connect(editor, SIGNAL(saved()), this, SLOT(updateLock()));      //update to see if Lock_all was (de)activated
+     connect(editor, SIGNAL(saved()), pref, SLOT(loadSettings()));
      connect(editor, SIGNAL(starting()), ti, SLOT(stop()));
      connect(editor, SIGNAL(finishing()), this, SLOT(warnings_on()));
+     connect(editor, SIGNAL(finishing()), pref, SLOT(loadSettings()));
 
      connect(actionLog_file, SIGNAL(toggled(bool)), log_action, SLOT(setChecked(bool)));
      connect(log_action, SIGNAL(toggled(bool)), actionLog_file, SLOT(setChecked(bool)));
@@ -188,7 +209,13 @@ Gui::Gui(){
      connect(actionKeep_window_proportions, SIGNAL(toggled(bool)), this, SLOT(staticProportions(bool)));
 }
 
-Gui::~Gui(){ delete font1; delete font2; delete font3; }
+Gui::~Gui(){
+     delete font1;
+     delete font2;
+     delete font3;
+//     delete parentalLockL;
+//     delete customL;
+}
 
 void Gui::showEvent(QShowEvent* show_window){
      minimize_restore_action->setText(tr("&Minimize"));
@@ -332,11 +359,7 @@ void Gui::keyPressEvent(QKeyEvent *kEvent){
 }
 
 void Gui::updateT(){
-     if(finishedExecuted)
-       reset();
-
      QDate myDate;
-
      QString tip1, tip2;
 
      if(shutdown_action->isChecked())
@@ -385,12 +408,12 @@ void Gui::updateT(){
 
        if(i>=86400){ //if one day and some time to go
          tip2 = (">= 1 " + tr("day"));
-         lcdL->setText(tr("day"));
-         if(bigI/86400 >= 10)
-           lcd->setNumDigits(4);
-         else
-           lcd->setNumDigits(3);
+         lcd->setNumDigits(3);
          lcd->display(bigI/86400);
+         if(lcd->value() > 1.1)
+           lcdL->setText(tr("days"));
+         else
+           lcdL->setText(tr("day"));
        }
        if(i<86400 && i>3600){ //if there is less than one day, show hours
          tip2 = (QString::number(i/3600) + " " + tr("hours"));
@@ -413,7 +436,7 @@ void Gui::updateT(){
          lcd->display(bigI/60);
        }
        if(i<=60){
-         tip2 = ("1 " + tr("seconds"));
+         tip2 = (QString::number(i) + " " + tr("seconds"));
          lcdL->setText(tr("seconds"));
          lcd->display(i);
        }
@@ -450,7 +473,7 @@ void Gui::updateT(){
          lcd->display(i);
        }
 
-       //this will ensure that the shutdown-type will be executed in case a few seconds were skipped
+     //this will ensure that the shutdown-type will be executed in case a few seconds were skipped
        if(i<=86390)
          n = 10; //any number to keep i in check
        if((i==0) || ((i>n) && (i>86390)))
@@ -476,7 +499,7 @@ void Gui::set(){
      if(lock->isChecked() || editor->getLockAll()){       //when OK-button is clicked and lock is checked
        QList<QWidget*> list;
        list << spin << radio1 << radio2 << lock << timeEdit << comboBox << targetTime
-            << minutes;
+            << minutes << pref->tab2;
        foreach(QWidget * ptr, list)
          ptr->setDisabled(true);
        power_actions->setDisabled(true);
@@ -489,6 +512,17 @@ void Gui::set(){
        reset_action->setEnabled(true);
        action_Reset->setEnabled(true);
      }
+
+/*   if((comboBox->currentIndex() == 0 && pref->shutdownM->currentIndex() == 6)
+        || (comboBox->currentIndex() == 1 && pref->rebootM->currentIndex() == 6)
+        || (comboBox->currentIndex() == 2 && pref->suspendM->currentIndex() == 5)
+        || (comboBox->currentIndex() == 3 && pref->hibernateM->currentIndex() == 5)){
+       if(!customL->isVisible())
+         customL->show();
+       statusBar()->addPermanentWidget(customL);
+     }
+     else
+       statusBar()->removeWidget(customL);*/
 }
 
 void Gui::Time(){
@@ -504,20 +538,17 @@ void Gui::Time(){
      bigI = i; //for more precise display with LCD
 }
 
-void Gui::saveWindowSize(){
+void Gui::saveLog(){
    #ifdef Q_OS_WIN32
      QString file(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/qshutdown/qshutdown.conf");
    #else //!Q_OS_WIN32
      QString file(QDir::homePath() + "/.qshutdown/qshutdown.conf");
    #endif //Q_OS_WIN32
-     QSettings settings(file, QSettings::NativeFormat);
+     QSettings settings(file, QSettings::IniFormat);
 
-     settings.setValue("MainWindow/size", size());
-     settings.setValue("MainWindow/keep_proportions", actionKeep_window_proportions->isChecked());
-}
+     settings.setValue("MainWindow/size",size());
+     settings.setValue("MainWindow/keep_proportions",actionKeep_window_proportions->isChecked());
 
-void Gui::saveLog(){
-     saveWindowSize();
      if(log_action->isChecked()){ //if logfile is set in the icon contextmenu
      #ifdef Q_OS_WIN32
        QFile logfile(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/qshutdown/log.txt");
@@ -535,7 +566,7 @@ void Gui::saveLog(){
        while(!logfile.atEnd())
          out.readLine();
        out << "[" << datetime.toString("yyyy.MM.dd hh:mm") << "] "
-           << 1/(60000.0/elapsedTime.elapsed()) << " Minutes uptime\n";
+           << 1/(60000.0/elapsedTime.elapsed()) << " minutes uptime\n";
        logfile.close();
 
 /******* if log.txt is bigger than set in preferences, delete first line *******/
@@ -559,27 +590,67 @@ void Gui::saveLog(){
 }
 
 void Gui::finished_(){
-     finishedExecuted = true;
-     saveLog();
+     if(!pref->quitAfterCountdown->isChecked())
+       reset();
      switch(comboBox->currentIndex()){
        case 0:
-         saveWindowSize();
+         if(pref->shutdownM->currentIndex()==0) { Power::automatic = true; }
+         if(pref->shutdownM->currentIndex()==1) { Power::gnome = true; }
+         if(pref->shutdownM->currentIndex()==2) { Power::kde = true; }
+         if(pref->shutdownM->currentIndex()==3) { Power::hal_ = true; }
+         if(pref->shutdownM->currentIndex()==4) { Power::consolekit = true; }
+         if(pref->shutdownM->currentIndex()==5) { Power::sudo = true; }
+         if(pref->shutdownM->currentIndex()==6) {
+           Power::user = true;
+           Power::myShutdown = pref->myShutdown;
+         }
+         saveLog();
          Power::shutdown();
          break;
        case 1:
-         saveWindowSize();
+         if(pref->rebootM->currentIndex()==0) { Power::automatic = true; }
+         if(pref->rebootM->currentIndex()==1) { Power::gnome = true; }
+         if(pref->rebootM->currentIndex()==2) { Power::kde = true; }
+         if(pref->rebootM->currentIndex()==3) { Power::hal_ = true; }
+         if(pref->rebootM->currentIndex()==4) { Power::consolekit = true; }
+         if(pref->rebootM->currentIndex()==5) { Power::sudo = true; }
+         if(pref->rebootM->currentIndex()==6) {
+           Power::user = true;
+           Power::myReboot = pref->myReboot;
+         }
+         saveLog();
          Power::reboot();
          break;
        case 2:
+         if(pref->suspendM->currentIndex()==0) { Power::automatic = true; }
+         if(pref->suspendM->currentIndex()==1) { Power::gnome = true; }
+         if(pref->suspendM->currentIndex()==2) { Power::hal_ = true; }
+         if(pref->suspendM->currentIndex()==3) { Power::upower_ = true; }
+         if(pref->suspendM->currentIndex()==4) { Power::devicekit = true; }
+         if(pref->suspendM->currentIndex()==5) {
+           Power::user = true;
+           Power::mySuspend = pref->mySuspend;
+         }
          if(pref->lockMyScreen){ Power::lockMyScreen = true; }
          Power::suspend();
          break;
        case 3:
+         if(pref->hibernateM->currentIndex()==0) { Power::automatic = true; }
+         if(pref->hibernateM->currentIndex()==1) { Power::gnome = true; }
+         if(pref->hibernateM->currentIndex()==2) { Power::hal_ = true; }
+         if(pref->hibernateM->currentIndex()==3) { Power::upower_ = true; }
+         if(pref->hibernateM->currentIndex()==4) { Power::devicekit = true; }
+         if(pref->hibernateM->currentIndex()==5) {
+           Power::user = true;
+           Power::myHibernate = pref->myHibernate;
+         }
          if(pref->lockMyScreen){ Power::lockMyScreen = true; }
          Power::hibernate();
          break;
        default:;
      }
+     if(pref->quitAfterCountdown->isChecked())
+       qApp->quit();
 }
 
 void Gui::hideEvent(QHideEvent* window_hide){
@@ -596,8 +667,7 @@ void Gui::closeEvent(QCloseEvent* window_close){
 }
 
 void Gui::beforeQuit(){
-     if(!finishedExecuted)
-       saveLog();
+     saveLog();
   #ifndef Q_OS_WIN32
      QDBusConnection::sessionBus().unregisterObject(OBJECT_NAME, QDBusConnection::UnregisterNode);
      QDBusConnection::sessionBus().unregisterService(SERVICE_NAME);
@@ -611,52 +681,33 @@ void Gui::loadSettings(){
 #else //!Q_OS_WIN32
      QString file(QDir::homePath() + "/.qshutdown/qshutdown.conf");
 #endif //Q_OS_WIN32
-     QSettings settings(file, QSettings::NativeFormat);
+     QSettings settings(file, QSettings::IniFormat);
 
      if(!settings.isWritable()){
        QTextStream myOutput;
        myOutput << "W: qshutdown.conf is not writable!" << endl;
      }
 
-     if(!QFile::exists(file)){
-       settings.setValue("Lock_all", false);
-       settings.setValue("Quit_on_close", false);
-       settings.setValue("Time/time_hour", 22);
-       settings.setValue("Time/time_minute", 00);
-       settings.setValue("Time/countdown_minutes", 60);
-       settings.setValue("Time/countdown_at_startup", false);
-       settings.setValue("Hide_at_startup", false);
-       settings.setValue("MainWindow/size", QSize(290, 280));
-       settings.setValue("MainWindow/keep_proportions", false);
-       settings.setValue("Fonts/font_type", "Times New Roman");
-       settings.setValue("Fonts/font1", 13);
-       settings.setValue("Fonts/font2", 18);
-       settings.setValue("Fonts/font3", 11);
-       settings.setValue("CheckBoxes/target_time", false);
-       settings.setValue("CheckBoxes/countdown", true);
-       settings.setValue("CheckBoxes/lock", true);
-       settings.setValue("CheckBoxes/warnings", true);
-       settings.setValue("Power/comboBox", 0);
-       settings.setValue("Logfile/logging", false);
-       settings.setValue("Logfile/size", 1.5);
-       settings.setValue("Lock_screen", true);
-      #ifndef Q_OS_WIN32
-       QFile autostartFile(QDir::homePath() + "/.config/autostart/qshutdown.desktop");
-       if(autostartFile.exists())
-         settings.setValue("Autostart", true);
-       else
-         settings.setValue("Autostart", false);
-      #endif
-     }
+     if(!settings.contains("Lock_all"))
+       settings.setValue("Lock_all",false);
+     if(!settings.contains("MainWindow/keep_proportions"))
+       settings.setValue("MainWindow/keep_proportions",true);
+    #ifndef Q_OS_WIN32
+     QFile autostartFile(QDir::homePath() + "/.config/autostart/qshutdown.desktop");
+     if(autostartFile.exists())
+       settings.setValue("Autostart",true);
      else
-       pref->autostartFile();
+       settings.setValue("Autostart",false);
+    #endif
+
+     pref->autostartFile();
 
 
 /***************** read files entries *****************/
      timeEdit->setTime(QTime(settings.value("Time/time_hour",22).toInt(),settings.value("Time/time_minute",00).toInt()));
      spin->setValue(settings.value("Time/countdown_minutes",60).toInt());
      resize(settings.value("MainWindow/size",QSize(290,280)).toSize());
-     actionKeep_window_proportions->setChecked(settings.value("MainWindow/keep_proportions",false).toBool());
+     actionKeep_window_proportions->setChecked(settings.value("MainWindow/keep_proportions",true).toBool());
      font1->setFamily(settings.value("Fonts/font_type","Times New Roman").toString());
      font2->setFamily(settings.value("Fonts/font_type","Times New Roman").toString());
      font3->setFamily(settings.value("Fonts/font_type","Times New Roman").toString());
@@ -679,6 +730,8 @@ void Gui::loadSettings(){
          QTimer::singleShot(2000, this, SLOT(hide()));
      }
 
+     staticProportions(settings.value("MainWindow/keep_proportions",true).toBool());
+
      lockEverything(settings.value("Lock_all",false).toBool());
 
      QList<QWidget*> list;
@@ -735,35 +788,36 @@ void Gui::lockEverything(bool actual){
                 << minutes << pref->comboBox << pref->timeEdit << pref->spin
                 << pref->radio1 << pref->radio2 << pref->stopHide
                 << pref->autostart << pref->lock << pref->countdown
-                << pref->log << pref->reset << pref->spinBox;
+                << pref->log << pref->reset << pref->spinBox << pref->tab2;
      foreach(QWidget * widgetPtr, widgetList)
        widgetPtr->setDisabled(actual);
 
      if(lock->isChecked() && timeRunning && !actual){
-       timeEdit->setDisabled(true);
-       radio1->setDisabled(true);
-       spin->setDisabled(true);
-       radio2->setDisabled(true);
-       comboBox->setDisabled(true);
-       targetTime->setDisabled(true);
-       minutes->setDisabled(true);
+       QList<QWidget*> widgetList2;
+       widgetList2 << timeEdit << spin << radio1  << radio2 << comboBox
+                   << targetTime << minutes << pref->tab2;
+       foreach(QWidget * widgetPtr2, widgetList2)
+             widgetPtr2->setDisabled(true);
      }
      if(timeRunning){
        reset_action->setDisabled(actual);
        action_Reset->setDisabled(actual);
-       if(!lock->isChecked()){
-         ok->hide();
-         minim->show();
-         minim->setFocus();
-         minim->setAutoDefault(true);
-       }
      }
      else{
        reset_action->setDisabled(true);
        action_Reset->setDisabled(true);
      }
+
+/*   if(actual){
+       if(!parentalLockL->isVisible())
+         parentalLockL->show();
+       statusBar()->addPermanentWidget(parentalLockL);
+     }
+     if(!actual && parentalLockL->isVisible())
+       statusBar()->removeWidget(parentalLockL);*/
 }
 void Gui::reset(){
+     timer->stop();
      setWindowTitle("'qshutdown'");
      toolButton->setText("Calendar");
      lcd->display(0);
@@ -771,20 +825,19 @@ void Gui::reset(){
      lcdL->setText(tr("minutes"));
      cal->setCalendarDate = QDate();
      cal->calendarDate = QDate();
-     if(finishedExecuted)
-       showNormal();
-     timer->stop();
+     showNormal();
      if(!ti->isActive())
        ti->start(30000);
      timeRunning = false;
-     finishedExecuted = false;
      minim->hide();
      ok->show();
+     pref->tab2->setEnabled(true);
      if(!editor->getLockAll())
        lockEverything(false);
      else loadSettings();
      action_Reset->setDisabled(true);
      reset_action->setDisabled(true);
+     //statusBar()->removeWidget(customL);
 }
 
 void Gui::getFonts(){
