@@ -30,6 +30,15 @@ Preferences::Preferences(QWidget *parent): QDialog(parent){
 
      setWindowFlags(Qt::Window);    //always in front
 
+   //Seconds won't be recognized, thus removing them (just in case).
+     QString timeEditFormat;
+     timeEditFormat = timeEdit->displayFormat();
+     if(timeEditFormat.contains(":ss"))
+       timeEditFormat.replace(QString(":ss"), QString(""));
+     if(timeEditFormat.contains(":s"))
+       timeEditFormat.replace(QString(":s"), QString(""));
+     timeEdit->setDisplayFormat(timeEditFormat);
+
 /***************** load settings from the conf file *****************/
 
 #ifdef Q_OS_WIN32
@@ -39,19 +48,24 @@ Preferences::Preferences(QWidget *parent): QDialog(parent){
 #else //!Q_OS_WIN32
      file = QDir::homePath() + "/.qshutdown/qshutdown.conf";
 #endif //Q_OS_WIN32
-     settings = new QSettings(file, QSettings::NativeFormat);
+     settings = new QSettings(file, QSettings::IniFormat);
 
      fonts = "Times New Roman";
      fontS1 = 13;
      fontS2 = 18;
      fontS3 = 11;
 
+     userDef1S = tr("Please input an user specified command for shutdown here");
+     userDef2S = tr("Please input an user specified command for reboot here");
+     userDef3S = tr("Please input an user specified command for suspend here");
+     userDef4S = tr("Please input an user specified command for hibernate here");
+
      msgBox = new QMessageBox(this);
      msgBox->setWindowTitle("Error");
      msgBox->setIcon(QMessageBox::Warning);
      msgBox->setWindowFlags(Qt::WindowStaysOnTopHint | Qt::Window);
-     msgBox->setInformativeText(tr("The File \"") + file + tr("\" is not writable!\n"
-     "Maybe you just don't have the permissions to do so."));
+     msgBox->setInformativeText(tr("The File \"%1\" is not writable!\n"
+     "Maybe you just don't have the permissions to do so.").arg(file));
 
      connect(buttonBox, SIGNAL(accepted()), this, SLOT(saveToConfFile()));
      connect(reset, SIGNAL(clicked(bool)), this, SLOT(resetSettings()));
@@ -59,11 +73,25 @@ Preferences::Preferences(QWidget *parent): QDialog(parent){
      connect(font2Spin, SIGNAL(valueChanged(int)), this, SLOT(fontSize2Changed(int)));
      connect(font3Spin, SIGNAL(valueChanged(int)), this, SLOT(fontSize3Changed(int)));
      connect(fontComboBox, SIGNAL(currentIndexChanged(QString)), this, SLOT(fontChanged(QString)));
-     connect(buttonBox, SIGNAL(rejected()), this, SLOT(resetFont()));
      connect(confEditButton, SIGNAL(clicked(bool)), this, SIGNAL(editConf()));
-     connect(this, SIGNAL(rejected()), this, SLOT(close()));
+     connect(shutdownM, SIGNAL(currentIndexChanged(int)), this, SLOT(enableUserDef1()));
+     connect(rebootM, SIGNAL(currentIndexChanged(int)), this, SLOT(enableUserDef2()));
+     connect(suspendM, SIGNAL(currentIndexChanged(int)), this, SLOT(enableUserDef3()));
+     connect(hibernateM, SIGNAL(currentIndexChanged(int)), this, SLOT(enableUserDef4()));
 
      loadSettings();
+
+     if(!QFile::exists(file))
+       saveToConfFile();
+
+     if(userDef1->isEnabled())
+       myShutdown = userDef1->toPlainText();
+     if(userDef2->isEnabled())
+       myReboot = userDef2->toPlainText();
+     if(userDef3->isEnabled())
+       mySuspend = userDef3->toPlainText();
+     if(userDef4->isEnabled())
+       myHibernate = userDef4->toPlainText();
 }
 
 Preferences::~Preferences(){ delete settings; }
@@ -79,6 +107,77 @@ void Preferences::showEvent(QShowEvent* show_pref){
      QWidget::showEvent(show_pref);
 }
 
+void Preferences::setFocusToUserDef(){
+     if(userDef4->isEnabled())
+       userDef4->setFocus();
+     if(userDef3->isEnabled())
+       userDef3->setFocus();
+     if(userDef2->isEnabled())
+       userDef2->setFocus();
+     if(userDef1->isEnabled())
+       userDef1->setFocus();
+}
+
+void Preferences::enableUserDef1(){
+     if(shutdownM->currentIndex() == 6){
+       userDef1->setEnabled(true);
+       userDef1->setFocus();
+       if(userDef1->toPlainText() == userDef1S)
+         userDef1->clear();
+     }
+     else{
+       userDef1->setEnabled(false);
+       if(userDef1->toPlainText() == "")
+         userDef1->setPlainText(userDef1S);
+       setFocusToUserDef();
+     }
+}
+
+void Preferences::enableUserDef2(){
+     if(rebootM->currentIndex() == 6){
+       userDef2->setEnabled(true);
+       userDef2->setFocus();
+       if(userDef2->toPlainText() == userDef2S)
+         userDef2->clear();
+     }
+     else{
+       userDef2->setEnabled(false);
+       if(userDef2->toPlainText() == "")
+         userDef2->setPlainText(userDef2S);
+       setFocusToUserDef();
+     }
+}
+
+void Preferences::enableUserDef3(){
+     if(suspendM->currentIndex() == 5){
+       userDef3->setEnabled(true);
+       userDef3->setFocus();
+       if(userDef3->toPlainText() == userDef3S)
+         userDef3->clear();
+     }
+     else{
+       userDef3->setEnabled(false);
+       if(userDef3->toPlainText() == "")
+         userDef3->setPlainText(userDef3S);
+       setFocusToUserDef();
+     }
+}
+
+void Preferences::enableUserDef4(){
+     if(hibernateM->currentIndex() == 5){
+       userDef4->setEnabled(true);
+       userDef4->setFocus();
+       if(userDef4->toPlainText() == userDef4S)
+         userDef4->clear();
+     }
+     else{
+       userDef4->setEnabled(false);
+       if(userDef4->toPlainText() == "")
+         userDef4->setPlainText(userDef4S);
+       setFocusToUserDef();
+     }
+}
+
 void Preferences::loadSettings(){
      if(settings->contains("PrefWindowSize/size"))
        resize(settings->value("PrefWindowSize/size").toSize());
@@ -100,34 +199,66 @@ void Preferences::loadSettings(){
      log->setChecked(settings->value("Logfile/logging",false).toBool());
      lockS->setChecked(settings->value("Lock_screen",true).toBool());
      autostart->setChecked(settings->value("Autostart").toBool());
-
+     shutdownM->setCurrentIndex(settings->value("Methods/shutdown",0).toInt());
+     userDef1->setPlainText(settings->value("Methods/myShutdown",userDef1S).toString());
+     rebootM->setCurrentIndex(settings->value("Methods/reboot",0).toInt());
+     userDef2->setPlainText(settings->value("Methods/myReboot",userDef2S).toString());
+     suspendM->setCurrentIndex(settings->value("Methods/suspend",0).toInt());
+     userDef3->setPlainText(settings->value("Methods/mySuspend",userDef3S).toString());
+     hibernateM->setCurrentIndex(settings->value("Methods/hibernate",0).toInt());
+     userDef4->setPlainText(settings->value("Methods/myHibernate",userDef4S).toString());
      lockMyScreen = settings->value("Lock_screen").toBool();
+     quitAfterCountdown->setChecked(settings->value("Quit_after_countdown_ended",false).toBool());
 }
 
 void Preferences::saveToConfFile(){
      if(settings->isWritable()){
-       settings->setValue("Power/comboBox", comboBox->currentIndex());
-       settings->setValue("Time/time_hour", timeEdit->time().hour());
-       settings->setValue("Time/time_minute", timeEdit->time().minute());
-       settings->setValue("Quit_on_close", stopHide->isChecked());
-       settings->setValue("Time/countdown_at_startup", countdown->isChecked());
-       settings->setValue("Hide_at_startup", hideMe->isChecked());
-       settings->setValue("Time/countdown_minutes", spin->value());
-       settings->setValue("Fonts/font_type", fontComboBox->currentText());
-       settings->setValue("Fonts/font1", font1Spin->value());
-       settings->setValue("Fonts/font2", font2Spin->value());
-       settings->setValue("Fonts/font3", font3Spin->value());
-       settings->setValue("Logfile/size", spinBox->value());
-       settings->setValue("CheckBoxes/target_time", radio1->isChecked());
-       settings->setValue("CheckBoxes/countdown", radio2->isChecked());
-       settings->setValue("CheckBoxes/lock", lock->isChecked());
-       settings->setValue("CheckBoxes/warnings", warn->isChecked());
-       settings->setValue("Logfile/logging", log->isChecked());
-       settings->setValue("Lock_screen", lockS->isChecked());
-       settings->setValue("Autostart", autostart->isChecked());
+       settings->setValue("Power/comboBox",comboBox->currentIndex());
+       settings->setValue("Time/time_hour",timeEdit->time().hour());
+       settings->setValue("Time/time_minute",timeEdit->time().minute());
+       settings->setValue("Quit_on_close",stopHide->isChecked());
+       settings->setValue("Time/countdown_at_startup",countdown->isChecked());
+       settings->setValue("Hide_at_startup",hideMe->isChecked());
+       settings->setValue("Time/countdown_minutes",spin->value());
+       settings->setValue("Fonts/font_type",fontComboBox->currentText());
+       settings->setValue("Fonts/font1",font1Spin->value());
+       settings->setValue("Fonts/font2",font2Spin->value());
+       settings->setValue("Fonts/font3",font3Spin->value());
+       settings->setValue("Logfile/size",spinBox->value());
+       settings->setValue("CheckBoxes/target_time",radio1->isChecked());
+       settings->setValue("CheckBoxes/countdown",radio2->isChecked());
+       settings->setValue("CheckBoxes/lock",lock->isChecked());
+       settings->setValue("CheckBoxes/warnings",warn->isChecked());
+       settings->setValue("Logfile/logging",log->isChecked());
+       settings->setValue("Lock_screen",lockS->isChecked());
+       settings->setValue("Autostart",autostart->isChecked());
+       settings->setValue("Methods/shutdown",shutdownM->currentIndex());
+       settings->setValue("Methods/myShutdown",userDef1->toPlainText());
+       settings->setValue("Methods/reboot",rebootM->currentIndex());
+       settings->setValue("Methods/myReboot",userDef2->toPlainText());
+       settings->setValue("Methods/suspend",suspendM->currentIndex());
+       settings->setValue("Methods/mySuspend",userDef3->toPlainText());
+       settings->setValue("Methods/hibernate",hibernateM->currentIndex());
+       settings->setValue("Methods/myHibernate",userDef4->toPlainText());
+       settings->setValue("Quit_after_countdown_ended",quitAfterCountdown->isChecked());
      }
      autostartFile(); //to create or to delete the autostart file
      lockScreen();    //set lockMyScreen to true or false according to lockS
+
+     if(userDef1->isEnabled())
+       myShutdown = userDef1->toPlainText();
+     else myShutdown = "";
+     if(userDef2->isEnabled())
+       myReboot = userDef2->toPlainText();
+     else myReboot = "";
+     if(userDef3->isEnabled())
+       mySuspend = userDef3->toPlainText();
+     else mySuspend = "";
+     if(userDef4->isEnabled())
+       myHibernate = userDef4->toPlainText();
+     else mySuspend = "";
+
+     this->close();
 }
 
 void Preferences::resetSettings(){
@@ -149,6 +280,15 @@ void Preferences::resetSettings(){
        warn->setChecked(true);
        log->setChecked(false);
        lockS->setChecked(true);
+       shutdownM->setCurrentIndex(0);
+       rebootM->setCurrentIndex(0);
+       suspendM->setCurrentIndex(0);
+       hibernateM->setCurrentIndex(0);
+       userDef1->setPlainText(userDef1S);
+       userDef2->setPlainText(userDef2S);
+       userDef3->setPlainText(userDef3S);
+       userDef4->setPlainText(userDef4S);
+       quitAfterCountdown->setChecked(false);
      }
 }
 
@@ -156,7 +296,8 @@ void Preferences::closeEvent(QCloseEvent* close_pref){
      isClosed = true;
      finishing(); //sends SIGNAL finishing()
      if(settings->isWritable())
-       settings->setValue("PrefWindowSize/size", size());
+       settings->setValue("PrefWindowSize/size",size());
+     resetFont();
      QWidget::closeEvent(close_pref);
 }
 
